CapabilityError

Enum CapabilityError 

#[non_exhaustive]
pub enum CapabilityError { Unsupported { family: &'static str, capability: Capability, }, Unimplemented { family: &'static str, capability: Capability, }, Unavailable { family: &'static str, capability: Capability, message: String, }, }
Static capability gating failure, returned by CapabilityNegotiation.

Decided without IO: it is a fact about whether a backend offers a capability, not whether a live call to it failed. The latter is BackendError.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Unsupported

The backend never offers the requested capability.

Fields

family: &'static str

Backend family.

capability: Capability

Capability that was requested.



Unimplemented

The backend is expected to offer the capability but has not implemented it yet.

Fields

family: &'static str

Backend family.

capability: Capability

Capability that was expected.



Unavailable

The backend can offer the capability in principle, but not in the current state.

Fields

family: &'static str

Backend family.

capability: Capability

Capability that is temporarily unavailable.

message: String

Additional explanation from the backend adapter.

Implementations

Source

impl CapabilityError

pub fn unsupported(family: &'static str, capability: Capability) -> Self

Creates an unsupported-capability error for the given backend.

pub fn unimplemented(family: &'static str, capability: Capability) -> Self

Creates an unimplemented-capability error for the given backend.

pub fn unavailable( family: &'static str, capability: Capability, message: impl Into<String>, ) -> Self

Creates an unavailable-capability error for the given backend.