#[non_exhaustive]pub enum CapabilityError {
Unsupported {
family: &'static str,
capability: Capability,
},
Unimplemented {
family: &'static str,
capability: Capability,
},
Unavailable {
family: &'static str,
capability: Capability,
message: String,
},
}Expand description
Static capability gating failure, returned by
CapabilityNegotiation.
Decided without IO: it is a fact about whether a backend offers a capability, not whether a
live call to it failed. The latter is BackendError.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Unsupported
The backend never offers the requested capability.
Unimplemented
The backend is expected to offer the capability but has not implemented it yet.
The backend can offer the capability in principle, but not in the current state.
Implementations
Sourceimpl CapabilityError
impl CapabilityError
Sourcepub fn unsupported(family: &'static str, capability: Capability) -> Self
pub fn unsupported(family: &'static str, capability: Capability) -> Self
Creates an unsupported-capability error for the given backend.
Sourcepub fn unimplemented(family: &'static str, capability: Capability) -> Self
pub fn unimplemented(family: &'static str, capability: Capability) -> Self
Creates an unimplemented-capability error for the given backend.
Creates an unavailable-capability error for the given backend.